(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     32834,        995]
NotebookOptionsPosition[     27162,        816]
NotebookOutlinePosition[     30192,        909]
CellTagsIndexPosition[     30052,        902]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Code for S10 Graphics and Animations", "Title"],

Cell[CellGroupData[{

Cell["Boucing Ball", "Subsection",
 CellTags->"Bouncing ball"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "Needs", "[", "\"\<DifferentialEquations`NDSolveProblems`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Needs", "[", "\"\<DifferentialEquations`NDSolveUtilities`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Needs", "[", "\"\<DifferentialEquations`InterpolatingFunctionAnatomy`\>\"",
    "]"}], ";"}]}], "Input",
 CellTags->"Bouncing ball"],

Cell["\<\
This defines a function which computes the solution from one bounce to the \
next.  The solution is computed up until the next time the path intersects \
the ramp.\
\>", "MathCaption",
 CellTags->"Bouncing ball"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OneBounce", "[", 
    RowBox[{"k_", ",", " ", "ramp_"}], "]"}], "[", 
   RowBox[{"{", 
    RowBox[{
    "t0_", ",", "x0_", ",", " ", "xp0_", ",", " ", "y0_", ",", " ", "yp0_"}], 
    "}"}], "]"}], " ", ":=", " ", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "sol", ",", " ", "t1", ",", " ", "x1", ",", " ", "xp1", ",", " ", "y1", 
      ",", " ", "yp1", ",", " ", "gramp", ",", " ", "gp"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sol", " ", "=", " ", 
      RowBox[{"First", "[", 
       RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"x", "''"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
            "0"}], ",", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"x", "'"}], "[", "t0", "]"}], "\[Equal]", " ", "xp0"}], 
           ",", " ", 
           RowBox[{
            RowBox[{"x", "[", "t0", "]"}], " ", "\[Equal]", " ", "x0"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "''"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
            RowBox[{"-", "9.8"}]}], " ", ",", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "'"}], "[", "t0", "]"}], " ", "\[Equal]", " ", 
            "yp0"}], ",", " ", 
           RowBox[{
            RowBox[{"y", "[", "t0", "]"}], " ", "\[Equal]", " ", "y0"}]}], 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"t", ",", "t0", ",", " ", "\[Infinity]"}], "}"}], ",", " ", 
         
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<EventLocator\>\"", ",", " ", 
            RowBox[{"\"\<Event\>\"", "\[RuleDelayed]", " ", 
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], " ", "-", " ", 
              RowBox[{"ramp", "[", 
               RowBox[{"x", "[", "t", "]"}], "]"}]}]}]}], "}"}]}], ",", 
         RowBox[{"MaxStepSize", "\[Rule]", "0.01"}], ",", 
         RowBox[{"MaxSteps", "\[Rule]", " ", "20000"}]}], "]"}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"t1", " ", "=", " ", 
      RowBox[{
       RowBox[{"InterpolatingFunctionDomain", "[", 
        RowBox[{"x", " ", "/.", " ", "sol"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x1", ",", "xp1", ",", "y1", ",", " ", "yp1"}], "}"}], " ", 
      "=", " ", 
      RowBox[{
       RowBox[{"Reflection", "[", 
        RowBox[{"k", ",", " ", "ramp"}], "]"}], "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "t1", "]"}], ",", " ", 
          RowBox[{
           RowBox[{"x", "'"}], "[", "t1", "]"}], ",", " ", 
          RowBox[{"y", "[", "t1", "]"}], ",", " ", 
          RowBox[{
           RowBox[{"y", "'"}], "[", "t1", "]"}]}], "}"}], " ", "/.", " ", 
        "sol"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Sow", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], " ", "/.", "sol"}], ",", 
         RowBox[{
         "t0", " ", "\[LessEqual]", " ", "t", " ", "\[LessEqual]", "  ", 
          "t1"}]}], "}"}], ",", " ", "\"\<X\>\""}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Sow", "[", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], " ", "/.", " ", "sol"}], ",", 
         RowBox[{
         "t0", " ", "\[LessEqual]", "  ", "t", " ", "\[LessEqual]", "  ", 
          "t1"}]}], "}"}], ",", " ", "\"\<Y\>\""}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Sow", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x1", ",", "y1"}], "}"}], ",", " ", "\"\<Bounces\>\""}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"t1", ",", " ", "x1", ",", "xp1", ",", "y1", ",", " ", "yp1"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.384506306418277*^9, 3.384506315717894*^9}},
 CellTags->"Bouncing ball"],

Cell["\<\
This defines the function for the bounce when the ball hits the ramp. The \
formula is based on reflection about the normal to the ramp assuming only the \
fraction k of energy is left after a bounce.\
\>", "MathCaption",
 CellTags->"Bouncing ball"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Reflection", "[", 
    RowBox[{"k_", ",", " ", "ramp_"}], "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", " ", "xp_", ",", " ", "y_", ",", " ", "yp_"}], "}"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gramp", ",", " ", "gp", ",", " ", "xpnew", ",", " ", "ypnew"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gramp", " ", "=", " ", 
      RowBox[{"-", 
       RowBox[{
        RowBox[{"ramp", "'"}], "[", "x", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"Not", "[", 
        RowBox[{"NumberQ", "[", "gramp", "]"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<Could not compute derivative \>\"", "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"gramp", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"ramp", "'"}], "[", "x", "]"}]}], ",", " ", "1"}], "}"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"gramp", ".", 
         RowBox[{"{", 
          RowBox[{"xp", ",", "yp"}], "}"}]}], " ", "\[Equal]", " ", "0"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<No reflection\>\"", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"gp", "=", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}], "}"}], " ", 
       RowBox[{"Reverse", "[", "gramp", "]"}]}]}], ";", "\[IndentingNewLine]",
      
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xpnew", ",", " ", "ypnew"}], "}"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "/", 
         RowBox[{"(", 
          RowBox[{"gramp", ".", "gramp"}], ")"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"gp", " ", 
          RowBox[{"gp", ".", 
           RowBox[{"{", 
            RowBox[{"xp", ",", "yp"}], "}"}]}]}], " ", "-", " ", 
         RowBox[{"gramp", " ", 
          RowBox[{"gramp", ".", 
           RowBox[{"{", 
            RowBox[{"xp", ",", " ", "yp"}], "}"}]}]}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "xpnew", ",", " ", "y", ",", " ", "ypnew"}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellTags->"Bouncing ball"],

Cell["\<\
This defines the function which runs the bouncing ball simulation for a given \
reflection ratio, ramp, and starting position.\
\>", "MathCaption",
 CellTags->"Bouncing ball"],

Cell[BoxData[
 RowBox[{"Clear", "[", "wavyramp", "]"}]], "Input",
 CellChangeTimes->{{3.384504594217244*^9, 3.384504599739366*^9}},
 CellTags->"Bouncing ball"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BouncingBall", "[", 
   RowBox[{"k_", ",", " ", "ramp_", ",", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_"}], "}"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"DynamicModule", "[", 
   RowBox[{
    RowBox[{"{", "data", "}"}], ",", 
    RowBox[{"Animate", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"ramp", "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xmin", ",", " ", "xmax"}], "}"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"xmin", ",", " ", "xmax"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ymin", "-", ".025"}], ",", " ", "ymax"}], "}"}]}], 
             "}"}]}], ",", " ", 
           RowBox[{"AspectRatio", "\[Rule]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"ymax", " ", "-", " ", "ymin"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"xmax", " ", "-", " ", "xmin"}], ")"}]}]}], ",", 
           RowBox[{"Filling", "\[Rule]", " ", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", " ", "0"}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", " ", 
            RowBox[{"8", " ", "72"}]}]}], "]"}], ",", 
         RowBox[{"ParametricPlot", "[", 
          RowBox[{
           RowBox[{"Evaluate", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Piecewise", "[", 
               RowBox[{"\"\<X\>\"", " ", "/.", "data"}], "]"}], ",", " ", 
              RowBox[{"Piecewise", "[", 
               RowBox[{"\"\<Y\>\"", " ", "/.", " ", "data"}], "]"}]}], "}"}], 
            "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"t", ",", "0", ",", "tt"}], "}"}], ",", " ", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"RGBColor", "[", 
             RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"PointSize", "[", ".025", "]"}], ",", 
            RowBox[{"Point", "[", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Piecewise", "[", 
                  RowBox[{"\"\<X\>\"", " ", "/.", "data"}], "]"}], ",", " ", 
                 RowBox[{"Piecewise", "[", 
                  RowBox[{"\"\<Y\>\"", " ", "/.", " ", "data"}], "]"}]}], 
                "}"}], "/.", 
               RowBox[{"t", "\[Rule]", " ", "tt"}]}], ")"}], "]"}]}], "}"}], 
          "]"}]}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"tt", ",", "0.001", ",", "\"\<time\>\""}], "}"}], ",", 
        "0.001", ",", "2.67"}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"SaveDefinitions", "\[Rule]", " ", "True"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Initialization", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"data", " ", "=", 
          RowBox[{"Reap", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Catch", "[", 
             RowBox[{
              RowBox[{"Sow", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"x0", ",", "y0"}], "}"}], ",", " ", 
                "\"\<Bounces\>\""}], "]"}], ";", "\[IndentingNewLine]", 
              RowBox[{"NestWhile", "[", 
               RowBox[{
                RowBox[{"OneBounce", "[", 
                 RowBox[{"k", ",", " ", "ramp"}], "]"}], ",", " ", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "x0", ",", "0", ",", "y0", ",", "0"}], 
                 "}"}], ",", " ", 
                RowBox[{"Function", "[", 
                 RowBox[{
                  RowBox[{"1", " ", "-", " ", 
                   RowBox[{
                    RowBox[{"#1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "/", 
                    RowBox[{"#2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], " ", ">", " ", 
                  "0.01"}], "]"}], ",", " ", "2", ",", " ", "25"}], "]"}]}], 
             "]"}], ",", "_", ",", " ", "Rule"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"data", " ", "=", " ", 
          RowBox[{"Last", "[", "data", "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"bounces", " ", "=", " ", 
          RowBox[{"(", 
           RowBox[{"\"\<Bounces\>\"", " ", "/.", " ", "data"}], ")"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"xmax", " ", "=", " ", 
          RowBox[{"Max", "[", 
           RowBox[{"bounces", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"xmin", " ", "=", " ", 
          RowBox[{"Min", "[", 
           RowBox[{"bounces", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"ymax", " ", "=", " ", 
          RowBox[{"Max", "[", 
           RowBox[{"bounces", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"ymin", " ", "=", " ", 
          RowBox[{"Min", "[", 
           RowBox[{"bounces", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"wavyramp", "[", "x_", "]"}], " ", ":=", " ", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"x", "<", "1"}], ",", 
            RowBox[{"1", "-", "x", "+", "  ", 
             RowBox[{".06", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"8.5", "Pi", " ", "x"}], "]"}]}]}], ",", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x", "-", "1"}], ")"}], "2"], "/", "4"}]}], "]"}]}], 
         ";"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"BouncingBall", "[", 
  RowBox[{".75", ",", " ", "wavyramp", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.249"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.382378761433864*^9, 3.382432206053246*^9, 3.384504090415389*^9, {
   3.384505716396228*^9, 3.384505787577943*^9}, 3.384505953259865*^9, {
   3.384506468292623*^9, 3.384506468525485*^9}},
 CellTags->"Bouncing ball"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Worm Animation", "Subsection",
 CellTags->"Worm Animation"],

Cell[BoxData[
 RowBox[{
  RowBox[{"torus", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "t", "]"}], 
        RowBox[{"(", 
         RowBox[{"2", " ", "+", " ", 
          RowBox[{
           RowBox[{"Cos", "[", "u", "]"}], "/", "3"}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], "/", "3"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", "t", "]"}], 
        RowBox[{"(", 
         RowBox[{"2", " ", "+", " ", 
          RowBox[{
           RowBox[{"Cos", "[", "u", "]"}], "/", "3"}]}], ")"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", " ", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"0", ",", "1", ",", "0"}], "]"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", " ", "None"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.3829788967951593`*^9, 3.382978989085253*^9}, 
   3.382979420414178*^9, 3.382983952849325*^9, 3.383058673759899*^9},
 CellTags->"Worm Animation"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TorusKnot", "[", 
   RowBox[{
    RowBox[{"n_Integer", "?", "Positive"}], ",", 
    RowBox[{"w_Integer", "?", "Positive"}]}], "]"}], ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"n", " ", "t"}], "]"}], 
     RowBox[{"(", 
      RowBox[{"2", " ", "+", " ", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"w", " ", "t"}], "]"}], "/", "1.25"}]}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"w", " ", "t"}], "]"}], "/", "1.25"}], ",", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"n", " ", "t"}], "]"}], 
     RowBox[{"(", 
      RowBox[{"2", " ", "+", " ", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"w", " ", "t"}], "]"}], "/", "1.25"}]}], ")"}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.382977057531118*^9, 3.382977058199222*^9}, 
   3.382977088833192*^9, {3.382977301335619*^9, 3.382977305976409*^9}},
 CellTags->"Worm Animation"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TorusKnotPlot", "[", 
    RowBox[{
     RowBox[{"n_Integer", "?", "Positive"}], ",", 
     RowBox[{"w_Integer", "?", "Positive"}], ",", 
     RowBox[{"steps_Integer", "?", "Positive"}]}], "]"}], "/;", 
   RowBox[{
    RowBox[{"GCD", "[", 
     RowBox[{"n", ",", "w"}], "]"}], "\[Equal]", "1"}]}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"num", ",", "kntpts"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"num", "=", " ", 
      RowBox[{"10", " ", "n", " ", "w"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"kntpts", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cylinder", "[", 
          RowBox[{"#", ",", 
           RowBox[{"1", "/", "7"}]}], "]"}], "&"}], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Partition", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"TorusKnot", "[", 
               RowBox[{"n", ",", "w"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", "0.", ",", 
                RowBox[{"2", " ", "\[Pi]"}], ",", 
                RowBox[{"\[Pi]", "/", "num"}]}], "}"}]}], "]"}], ",", "2", 
            ",", "1"}], "]"}], "/.", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"a_List", ",", "b_List"}], "}"}], "\[RuleDelayed]", 
           RowBox[{"{", 
            RowBox[{"a", ",", " ", 
             RowBox[{
              RowBox[{"1.12", " ", 
               RowBox[{"(", 
                RowBox[{"b", "-", "a"}], ")"}]}], "+", "a"}]}], "}"}]}]}], 
         ")"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Graphics3D", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", 
             RowBox[{"{", 
              RowBox[{"Yellow", ",", 
               RowBox[{"Thickness", "[", ".0025", "]"}]}], "}"}], "]"}], ",", 
            "Yellow", ",", 
            RowBox[{"Take", "[", 
             RowBox[{"kntpts", ",", 
              RowBox[{"Min", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"steps", " ", "2"}], ",", 
                 RowBox[{"Length", "[", "kntpts", "]"}]}], "}"}], "]"}]}], 
             "]"}]}], "}"}], "]"}], ",", "torus"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
       RowBox[{"Boxed", "\[Rule]", " ", "False"}], ",", 
       RowBox[{"Background", "\[Rule]", " ", 
        RowBox[{"GrayLevel", "[", ".25", "]"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", " ", 
        RowBox[{"6", " ", "72"}]}], ",", 
       RowBox[{"ViewPoint", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", ".1"}], ",", 
          RowBox[{"-", "3.2"}], ",", ".15"}], "}"}]}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellTags->"Worm Animation"],

Cell[BoxData[
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"TorusKnotPlot", "[", 
    RowBox[{"3", ",", "5", ",", "k"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", "155", ",", "1"}], "}"}], ",", 
   RowBox[{"DisplayAllSteps", "\[Rule]", " ", "True"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Worm Animation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Random Walks", "Subsection",
 CellTags->"Random walks"],

Cell[CellGroupData[{

Cell["1D off-lattice random walks", "Subsubsection",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomWalk", "[", "n_", "]"}], ":=", 
  RowBox[{"Accumulate", "[", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", "n", "}"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{"RandomWalk", "[", "5", "]"}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomWalk2", "[", "n_", "]"}], ":=", 
  RowBox[{"FoldList", "[", 
   RowBox[{"Plus", ",", "0", ",", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", "n", "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{"RandomWalk2", "[", "5", "]"}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"RandomWalk", "[", "1000", "]"}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1D lattice random walk", "Subsubsection",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomWalk3", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Accumulate", "[", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", "n", "}"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{"RandomWalk3", "[", "5", "]"}]], "Input",
 CellTags->"Random walks"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D off-lattice random walks", "Subsubsection",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomWalk4", "[", "n_", "]"}], ":=", 
  RowBox[{"Accumulate", "[", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "2"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"RandomWalk4", "[", "1000", "]"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomWalk5", "[", "n_", "]"}], ":=", 
  RowBox[{"FoldList", "[", 
   RowBox[{"Plus", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], ",", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "2"}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{"RandomWalk5", "[", "5", "]"}]], "Input",
 CellTags->"Random walks"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D lattice random walks", "Subsubsection",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomWalk6", "[", "n_", "]"}], ":=", 
  RowBox[{"Accumulate", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"RandomChoice", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{"RandomInteger", "[", "]"}]]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{"RandomInteger", "[", "]"}]], ",", "0"}], "}"}]}], "}"}], 
      "]"}], ",", 
     RowBox[{"{", "n", "}"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{"RandomWalk6", "[", "5", "]"}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomWalk7", "[", "n_", "]"}], ":=", 
  RowBox[{"Accumulate", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"RotateRight", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"RandomInteger", "[", "]"}]]}], "}"}], ",", 
       RowBox[{"RandomInteger", "[", "]"}]}], "]"}], ",", 
     RowBox[{"{", "n", "}"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomWalk8", "[", "n_", "]"}], ":=", 
  RowBox[{"FoldList", "[", 
   RowBox[{"Plus", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], ",", 
    RowBox[{"RandomInteger", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "2"}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{"RandomWalk8", "[", "5", "]"}]], "Input",
 CellTags->"Random walks"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomWalk9", "[", "n_", "]"}], ":=", 
  RowBox[{"Accumulate", "[", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "2"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Random walks"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1061, 791},
WindowMargins->{{Automatic, 98}, {-20, Automatic}},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (April 25, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Bouncing ball"->{
  Cell[668, 27, 62, 1, 34, "Subsection",
   CellTags->"Bouncing ball"],
  Cell[733, 30, 428, 13, 58, "Input",
   CellTags->"Bouncing ball"],
  Cell[1164, 45, 222, 5, 40, "MathCaption",
   CellTags->"Bouncing ball"],
  Cell[1389, 52, 4362, 114, 208, "Input",
   CellTags->"Bouncing ball"],
  Cell[5754, 168, 259, 5, 40, "MathCaption",
   CellTags->"Bouncing ball"],
  Cell[6016, 175, 2654, 77, 193, "Input",
   CellTags->"Bouncing ball"],
  Cell[8673, 254, 185, 4, 40, "MathCaption",
   CellTags->"Bouncing ball"],
  Cell[8861, 260, 159, 3, 27, "Input",
   CellTags->"Bouncing ball"],
  Cell[15347, 421, 404, 9, 27, "Input",
   CellTags->"Bouncing ball"]},
 "Worm Animation"->{
  Cell[15788, 435, 65, 1, 34, "Subsection",
   CellTags->"Worm Animation"],
  Cell[15856, 438, 1231, 34, 71, "Input",
   CellTags->"Worm Animation"],
  Cell[17090, 474, 991, 30, 71, "Input",
   CellTags->"Worm Animation"],
  Cell[18084, 506, 3366, 92, 251, "Input",
   CellTags->"Worm Animation"],
  Cell[21453, 600, 378, 9, 51, "Input",
   CellTags->"Worm Animation"]},
 "Random walks"->{
  Cell[21868, 614, 61, 1, 26, "Subsection",
   CellTags->"Random walks"],
  Cell[21954, 619, 79, 1, 25, "Subsubsection",
   CellTags->"Random walks"],
  Cell[22036, 622, 317, 10, 27, "Input",
   CellTags->"Random walks"],
  Cell[22356, 634, 90, 2, 27, "Input",
   CellTags->"Random walks"],
  Cell[22449, 638, 359, 11, 27, "Input",
   CellTags->"Random walks"],
  Cell[22811, 651, 91, 2, 27, "Input",
   CellTags->"Random walks"],
  Cell[23047, 662, 74, 1, 25, "Subsubsection",
   CellTags->"Random walks"],
  Cell[23124, 665, 331, 10, 27, "Input",
   CellTags->"Random walks"],
  Cell[23458, 677, 91, 2, 27, "Input",
   CellTags->"Random walks"],
  Cell[23586, 684, 79, 1, 25, "Subsubsection",
   CellTags->"Random walks"],
  Cell[23668, 687, 345, 11, 27, "Input",
   CellTags->"Random walks"],
  Cell[24016, 700, 205, 5, 27, "Input",
   CellTags->"Random walks"],
  Cell[24224, 707, 438, 14, 27, "Input",
   CellTags->"Random walks"],
  Cell[24665, 723, 91, 2, 27, "Input",
   CellTags->"Random walks"],
  Cell[24793, 730, 75, 1, 25, "Subsubsection",
   CellTags->"Random walks"],
  Cell[24871, 733, 731, 23, 33, "Input",
   CellTags->"Random walks"],
  Cell[25605, 758, 91, 2, 27, "Input",
   CellTags->"Random walks"],
  Cell[25699, 762, 534, 16, 33, "Input",
   CellTags->"Random walks"],
  Cell[26236, 780, 441, 14, 27, "Input",
   CellTags->"Random walks"],
  Cell[26680, 796, 91, 2, 27, "Input",
   CellTags->"Random walks"],
  Cell[26774, 800, 348, 11, 27, "Input",
   CellTags->"Random walks"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Bouncing ball", 27456, 826},
 {"Worm Animation", 28133, 845},
 {"Random walks", 28523, 856}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 53, 0, 76, "Title"],
Cell[CellGroupData[{
Cell[668, 27, 62, 1, 34, "Subsection",
 CellTags->"Bouncing ball"],
Cell[733, 30, 428, 13, 58, "Input",
 CellTags->"Bouncing ball"],
Cell[1164, 45, 222, 5, 40, "MathCaption",
 CellTags->"Bouncing ball"],
Cell[1389, 52, 4362, 114, 208, "Input",
 CellTags->"Bouncing ball"],
Cell[5754, 168, 259, 5, 40, "MathCaption",
 CellTags->"Bouncing ball"],
Cell[6016, 175, 2654, 77, 193, "Input",
 CellTags->"Bouncing ball"],
Cell[8673, 254, 185, 4, 40, "MathCaption",
 CellTags->"Bouncing ball"],
Cell[8861, 260, 159, 3, 27, "Input",
 CellTags->"Bouncing ball"],
Cell[9023, 265, 6321, 154, 348, "Input"],
Cell[15347, 421, 404, 9, 27, "Input",
 CellTags->"Bouncing ball"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15788, 435, 65, 1, 34, "Subsection",
 CellTags->"Worm Animation"],
Cell[15856, 438, 1231, 34, 71, "Input",
 CellTags->"Worm Animation"],
Cell[17090, 474, 991, 30, 71, "Input",
 CellTags->"Worm Animation"],
Cell[18084, 506, 3366, 92, 251, "Input",
 CellTags->"Worm Animation"],
Cell[21453, 600, 378, 9, 51, "Input",
 CellTags->"Worm Animation"]
}, Closed]],
Cell[CellGroupData[{
Cell[21868, 614, 61, 1, 26, "Subsection",
 CellTags->"Random walks"],
Cell[CellGroupData[{
Cell[21954, 619, 79, 1, 25, "Subsubsection",
 CellTags->"Random walks"],
Cell[22036, 622, 317, 10, 27, "Input",
 CellTags->"Random walks"],
Cell[22356, 634, 90, 2, 27, "Input",
 CellTags->"Random walks"],
Cell[22449, 638, 359, 11, 27, "Input",
 CellTags->"Random walks"],
Cell[22811, 651, 91, 2, 27, "Input",
 CellTags->"Random walks"],
Cell[22905, 655, 105, 2, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23047, 662, 74, 1, 25, "Subsubsection",
 CellTags->"Random walks"],
Cell[23124, 665, 331, 10, 27, "Input",
 CellTags->"Random walks"],
Cell[23458, 677, 91, 2, 27, "Input",
 CellTags->"Random walks"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23586, 684, 79, 1, 25, "Subsubsection",
 CellTags->"Random walks"],
Cell[23668, 687, 345, 11, 27, "Input",
 CellTags->"Random walks"],
Cell[24016, 700, 205, 5, 27, "Input",
 CellTags->"Random walks"],
Cell[24224, 707, 438, 14, 27, "Input",
 CellTags->"Random walks"],
Cell[24665, 723, 91, 2, 27, "Input",
 CellTags->"Random walks"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24793, 730, 75, 1, 25, "Subsubsection",
 CellTags->"Random walks"],
Cell[24871, 733, 731, 23, 33, "Input",
 CellTags->"Random walks"],
Cell[25605, 758, 91, 2, 27, "Input",
 CellTags->"Random walks"],
Cell[25699, 762, 534, 16, 33, "Input",
 CellTags->"Random walks"],
Cell[26236, 780, 441, 14, 27, "Input",
 CellTags->"Random walks"],
Cell[26680, 796, 91, 2, 27, "Input",
 CellTags->"Random walks"],
Cell[26774, 800, 348, 11, 27, "Input",
 CellTags->"Random walks"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
